@@ -31,7 +31,10 @@ sub add_group_validator {
     Hyper::Singleton::Container::Validator::Group
         ->singleton()
         ->add_validators_of({
-            $self->get_name() => \@validators,
+            $self->get_name() => [
+                @{$self->get_group_validators() || []},
+                @validators,
+            ],
         });
 
     return $self;
@@ -226,19 +229,19 @@ $Author: ac0v $
 
 =item Id
 
-$Id: Group.pm 317 2008-02-16 01:52:33Z ac0v $
+$Id: Group.pm 474 2008-05-29 13:25:22Z ac0v $
 
 =item Revision
 
-$Revision: 317 $
+$Revision: 474 $
 
 =item Date
 
-$Date: 2008-02-16 02:52:33 +0100 (Sat, 16 Feb 2008) $
+$Date: 2008-05-29 15:25:22 +0200 (Thu, 29 May 2008) $
 
 =item HeadURL
 
-$HeadURL: http://svn.hyper-framework.org/Hyper/Hyper/trunk/lib/Hyper/Control/Validator/Group.pm $
+$HeadURL: file:///srv/cluster/svn/repos/Hyper/Hyper/trunk/lib/Hyper/Control/Validator/Group.pm $
 
 =back
 
