@@ -18,13 +18,16 @@ sub add_single_validator {
     Hyper::Singleton::Container::Validator::Single
         ->singleton()
         ->add_validators_of({
-            $self->get_name() => \@validators,
+            $self->get_name() => [
+                @{$self->get_single_validators() || []},
+                @validators,
+            ],
         });
 
     return $self;
 }
 
-sub get_single_validators {
+sub get_single_validators {use Data::Dumper;
     return Hyper::Singleton::Container::Validator::Single
         ->singleton()
         ->get_validators_of(shift->get_name());
@@ -51,7 +54,7 @@ sub is_valid {
 
     return ! grep {
         ! $_->is_valid(@values);
-    } @{$self->get_single_validators()};
+    } @{$self->get_single_validators() || []};
 }
 
 1;
@@ -158,19 +161,19 @@ $Author: ac0v $
 
 =item Id
 
-$Id: Single.pm 317 2008-02-16 01:52:33Z ac0v $
+$Id: Single.pm 474 2008-05-29 13:25:22Z ac0v $
 
 =item Revision
 
-$Revision: 317 $
+$Revision: 474 $
 
 =item Date
 
-$Date: 2008-02-16 02:52:33 +0100 (Sat, 16 Feb 2008) $
+$Date: 2008-05-29 15:25:22 +0200 (Do, 29 Mai 2008) $
 
 =item HeadURL
 
-$HeadURL: http://svn.hyper-framework.org/Hyper/Hyper/trunk/lib/Hyper/Control/Validator/Single.pm $
+$HeadURL: http://svn.hyper-framework.org/Hyper/Hyper/branches/0.04/lib/Hyper/Control/Validator/Single.pm $
 
 =back
 
