@@ -142,7 +142,7 @@ Class::Std::Storable
 
 =item HeadURL
 
- $HeadURL: http://svn.hyper-framework.org/Hyper/Hyper/trunk/lib/Hyper/Debug.pm $
+ $HeadURL: file:///srv/cluster/svn/repos/Hyper/Hyper/trunk/lib/Hyper/Debug.pm $
 
 =back
 
