@@ -110,7 +110,7 @@ $Date: 2008-02-16 02:52:33 +0100 (Sat, 16 Feb 2008) $
 
 =item HeadURL
 
-$HeadURL: http://svn.hyper-framework.org/Hyper/Hyper/trunk/lib/Hyper/Name.pm $
+$HeadURL: file:///srv/cluster/svn/repos/Hyper/Hyper/trunk/lib/Hyper/Name.pm $
 
 =back
 
